@@ -1,6 +1,6 @@
 package Pb::Command::Context;
 
-our $VERSION = '0.01_03'; # TRIAL VERSION
+our $VERSION = '0.01_04'; # TRIAL VERSION
 
 use Moo;
 use 5.14.0;
@@ -93,7 +93,8 @@ sub _prep_filename
 sub _extrapolate_run_mode
 {
 	my ($self) = @_;
-	return 'NOACTION' if $self->_opts->{pretend};
+	return 'NOACTION'  if $self->_opts->{pretend};
+	return 'ASKACTION' if $self->_opts->{interactive};
 	return 'ACTION';
 }
 
@@ -397,7 +398,7 @@ Pb::Command::Context - context object for a Pb command
 
 =head1 VERSION
 
-This document describes version 0.01_03 of Pb::Command::Context.
+This document describes version 0.01_04 of Pb::Command::Context.
 
 =head1 DESCRIPTION
 
@@ -493,7 +494,7 @@ Get a logfile ready for outputting to.
 
 =head2 prep_pidfile
 
-Build a Proc::Pidfile object and handle any "already running" issues.
+Build a L<Proc::Pidfile> object and handle any "already running" issues.
 
 =head1 AUTHOR
 
